[ooo-build-commit] .: 5 commits - download.in patches/dev300
René Engelhard
rene at kemper.freedesktop.org
Sat Jul 31 12:46:40 PDT 2010
download.in | 12 ---
patches/dev300/apply | 3
patches/dev300/debian-dictionary.diff | 4 -
patches/dev300/desktop-initial-preference-5.diff | 66 --------------------
patches/dev300/open-url-support-iceanimals.diff | 32 ++++-----
patches/dev300/sensible-browser.diff | 26 +++----
patches/dev300/system-lpsolve-link-with-colamd.diff | 4 -
patches/dev300/system-lpsolve-rpath.diff | 2
patches/dev300/ubuntu-dictionary.diff | 4 -
9 files changed, 34 insertions(+), 119 deletions(-)
New commits:
commit 554181ce1ae40666b629fc472f7e4532bad3999e
Author: Rene Engelhard <rene at debian.org>
Date: Sat Jul 31 15:46:16 2010 -0400
update some (Debian-only) system-lpsolve patches for ooo330-m2
* patches/dev300/system-lpsolve-link-with-colamd.diff:
* patches/dev300/system-lpsolve-rpath.diff:
diff --git a/patches/dev300/system-lpsolve-link-with-colamd.diff b/patches/dev300/system-lpsolve-link-with-colamd.diff
index 3c8e6f6..54de2bd 100644
--- a/patches/dev300/system-lpsolve-link-with-colamd.diff
+++ b/patches/dev300/system-lpsolve-link-with-colamd.diff
@@ -20,8 +20,8 @@ diff -u -u -r1.3 makefile.mk
--- configure.in-old 2009-10-23 10:40:02.000000000 +0200
+++ configure.in 2009-10-23 10:40:35.000000000 +0200
-@@ -5380,6 +5380,7 @@
- [ AC_MSG_ERROR(lpsolve headers not found.)], [])
+@ -5185,6 +5185,7 @@
+ # some systems need this. Like Ubuntu....
AC_CHECK_LIB(m, floor)
AC_CHECK_LIB(dl, dlopen)
+ AC_CHECK_LIB(colamd, colamd)
diff --git a/patches/dev300/system-lpsolve-rpath.diff b/patches/dev300/system-lpsolve-rpath.diff
index a6dced3..24c72cc 100644
--- a/patches/dev300/system-lpsolve-rpath.diff
+++ b/patches/dev300/system-lpsolve-rpath.diff
@@ -1,7 +1,7 @@
--- solenv/inc/libs.mk-old 2008-04-29 12:50:10.000000000 +0200
+++ solenv/inc/libs.mk 2008-04-29 12:51:27.000000000 +0200
@@ -340,7 +340,13 @@
- MYTHESLIB=-lmythes
+ MYTHESLIB=-lmythes-1.2
.ENDIF
PYUNOLIB=-lpyuno
+.IF "$(SYSTEM_LPSOLVE)" == "YES"
commit a1b8583a8c6b884e4a78dee88df41712f95f5d02
Author: Rene Engelhard <rene at debian.org>
Date: Sat Jul 31 15:43:14 2010 -0400
update (gnome-)open-url.sh touching Debian patches for ooo330-m2
* patches/dev300/open-url-support-iceanimals.diff:
* patches/dev300/sensible-browser.diff:
diff --git a/patches/dev300/open-url-support-iceanimals.diff b/patches/dev300/open-url-support-iceanimals.diff
index 5e31d61..3928954 100644
--- a/patches/dev300/open-url-support-iceanimals.diff
+++ b/patches/dev300/open-url-support-iceanimals.diff
@@ -2,21 +2,21 @@ Index: open-url.sh
===================================================================
--- shell/source/unix/misc/open-url.sh (Revision 277618)
+++ shell/source/unix/misc/open-url.sh (Arbeitskopie)
-@@ -52,7 +52,7 @@
+@@ -58,7 +58,7 @@
exit 0
- else
- # mozilla derivates may need -remote semantics
-- for i in thunderbird mozilla netscape; do
-+ for i in icedove thunderbird iceape mozilla netscape; do
- mailer=`which $i`
- if [ ! -z "$mailer" ]; then
- run_mozilla "$mailer" "$1"
-@@ -69,7 +69,7 @@
+ fi
+ # mozilla derivates may need -remote semantics
+- for i in thunderbird mozilla netscape; do
++ for i in icedove thunderbird iceape mozilla netscape; do
+ mailer=`which $i`
+ if [ ! -z "$mailer" ]; then
+ run_mozilla "$mailer" "$1"
+@@ -84,7 +84,7 @@
exit 0
- else
- # mozilla derivates may need -remote semantics
-- for i in firefox mozilla netscape; do
-+ for i in iceweasel firefox iceape mozilla netscape; do
- browser=`which $i`
- if [ ! -z "$browser" ]; then
- run_mozilla "$browser" "$1"
+ fi
+ # mozilla derivates may need -remote semantics
+- for i in firefox mozilla netscape; do
++ for i in iceweasel firefox iceape mozilla netscape; do
+ browser=`which $i`
+ if [ ! -z "$browser" ]; then
+ run_mozilla "$browser" "$1"
diff --git a/patches/dev300/sensible-browser.diff b/patches/dev300/sensible-browser.diff
index 0bcdc79..aeb901f 100644
--- a/patches/dev300/sensible-browser.diff
+++ b/patches/dev300/sensible-browser.diff
@@ -5,17 +5,12 @@ retrieving revision 1.3
Index: shell/source/unix/misc/kde-open-url.sh
@@ -48,13 +43,14 @@ retrieving revision 1.2
diff -u -u -r1.2 open-url.sh
--- shell/source/unix/misc/open-url.sh 10 May 2004 13:08:30 -0000 1.2
+++ shell/source/unix/misc/open-url.sh 6 Jun 2005 09:43:06 -0000
-@@ -67,6 +67,9 @@
- if [ ! -z "$BROWSER" ]; then
+@ -79,6 +79,10 @@
$BROWSER "$1" &
exit 0
-+ elif [ -x /usr/bin/sensible-browser ]; then
+ fi
++ if [ -x /usr/bin/sensible-browser ]; then
+ sensible-browser "$1"
+ exit 0
- else
- # mozilla derivates may need -remote semantics
- for i in firefox mozilla netscape; do
++ fi
+ # mozilla derivates may need -remote semantics
+ for i in firefox mozilla netscape; do
+ browser=`which $i`
commit 86e9b35aa24843aa16868de621b19e6e698119e5
Author: Rene Engelhard <rene at debian.org>
Date: Sat Jul 31 15:42:45 2010 -0400
sun.dic -> oracle.dic
* patches/dev300/debian-dictionary.diff:
* patches/dev300/ubuntu-dictionary.diff:
diff --git a/patches/dev300/debian-dictionary.diff b/patches/dev300/debian-dictionary.diff
index 612c252..aadac21 100644
--- a/patches/dev300/debian-dictionary.diff
+++ b/patches/dev300/debian-dictionary.diff
@@ -4,7 +4,7 @@
ZIP1TARGET = $(WORDBOOK_ALL_TARGET)
--ZIP1LIST = sun.dic
+-ZIP1LIST = oracle.dic
+ZIP1LIST = Debian.dic
@@ -15,7 +15,7 @@
<desc>Specifies the custom dictionaries to be used. The Ignore list (IgnoreAllList (All)) is administered in the RAM only for the current spellcheck.</desc>
<label>Custom dictionaries</label>
</info>
-- <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;sun.dic</value>
+- <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;oracle.dic</value>
+ <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;Debian.dic</value>
</prop>
<prop oor:name="IsUseDictionaryList" oor:type="xs:boolean">
diff --git a/patches/dev300/ubuntu-dictionary.diff b/patches/dev300/ubuntu-dictionary.diff
index 0aa34d6..fabac90 100644
--- a/patches/dev300/ubuntu-dictionary.diff
+++ b/patches/dev300/ubuntu-dictionary.diff
@@ -4,7 +4,7 @@
ZIP1TARGET = $(WORDBOOK_ALL_TARGET)
--ZIP1LIST = sun.dic
+-ZIP1LIST = oracle.dic
+ZIP1LIST = Ubuntu.dic
@@ -15,7 +15,7 @@
<desc>Specifies the custom dictionaries to be used. The Ignore list (IgnoreAllList (All)) is administered in the RAM only for the current spellcheck.</desc>
<label>Custom dictionaries</label>
</info>
-- <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;sun.dic</value>
+- <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;oracle.dic</value>
+ <value oor:separator=";">IgnoreAllList;soffice.dic;standard.dic;Ubuntu.dic</value>
</prop>
<prop oor:name="IsUseDictionaryList" oor:type="xs:boolean">
commit a934bb89d8838a6d279951b870b525c69a340312
Author: Rene Engelhard <rene at debian.org>
Date: Sat Jul 31 15:26:19 2010 -0400
remove integrated desktop-initial-preference-5.diff
* patches/dev300/apply:
* patches/dev300/desktop-initial-preference-5.diff:
diff --git a/patches/dev300/apply b/patches/dev300/apply
index 9978fbf..d88c86c 100644
--- a/patches/dev300/apply
+++ b/patches/dev300/apply
@@ -424,9 +424,6 @@ desktop-safer-user-dir-perm.diff, i#62858, pmladek
# Added support for "application/octet-stream" mime type in package manager
desktop-application-octet-stream-mime-type.diff, i#73301, flr
-# set InitialPreference=5 to get prefereed over okular (2) and k* (3)
-desktop-initial-preference-5.diff
-
# select the java automatically when the system javavendors.xml is modified
# do not force to do it the user manually
jvmfwk-modified-javavendors-xml.diff, i#99619, pmladek
diff --git a/patches/dev300/desktop-initial-preference-5.diff b/patches/dev300/desktop-initial-preference-5.diff
deleted file mode 100644
index 8385242..0000000
--- a/patches/dev300/desktop-initial-preference-5.diff
+++ /dev/null
@@ -1,66 +0,0 @@
----
- sysui/desktop/menus/base.desktop | 1 +
- sysui/desktop/menus/calc.desktop | 1 +
- sysui/desktop/menus/draw.desktop | 1 +
- sysui/desktop/menus/impress.desktop | 1 +
- sysui/desktop/menus/math.desktop | 1 +
- sysui/desktop/menus/writer.desktop | 1 +
- 6 files changed, 6 insertions(+), 0 deletions(-)
-
-diff --git sysui/desktop/menus/base.desktop sysui/desktop/menus/base.desktop
-index 89d0a20..9497666 100644
---- sysui/desktop/menus/base.desktop
-+++ sysui/desktop/menus/base.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.database;application/vnd.sun.xml.bas
- Name=%PRODUCTNAME Base
- GenericName=Database Development
- Comment=Manage databases, create queries and reports to track and manage your information by using Base.
-+InitialPreference=5
-diff --git sysui/desktop/menus/calc.desktop sysui/desktop/menus/calc.desktop
-index e49b114..bc0c9ee 100644
---- sysui/desktop/menus/calc.desktop
-+++ sysui/desktop/menus/calc.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.spreadsheet;application/vnd.oasis.op
- Name=%PRODUCTNAME Calc
- GenericName=Spreadsheet
- Comment=Perform calculation, analyze information and manage lists in spreadsheets by using Calc.
-+InitialPreference=5
-diff --git sysui/desktop/menus/draw.desktop sysui/desktop/menus/draw.desktop
-index 438d603..42db7c6 100644
---- sysui/desktop/menus/draw.desktop
-+++ sysui/desktop/menus/draw.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.graphics;application/vnd.oasis.opend
- Name=%PRODUCTNAME Draw
- GenericName=Drawing Program
- Comment=Create and edit drawings, flow charts, and logos by using Draw.
-+InitialPreference=5
-diff --git sysui/desktop/menus/impress.desktop sysui/desktop/menus/impress.desktop
-index 0aa3cde..90df11a 100644
---- sysui/desktop/menus/impress.desktop
-+++ sysui/desktop/menus/impress.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.presentation;application/vnd.oasis.o
- Name=%PRODUCTNAME Impress
- GenericName=Presentation
- Comment=Create and edit presentations for slideshows, meeting and Web pages by using Impress.
-+InitialPreference=5
-diff --git sysui/desktop/menus/math.desktop sysui/desktop/menus/math.desktop
-index 15a6d42..f97536d 100644
---- sysui/desktop/menus/math.desktop
-+++ sysui/desktop/menus/math.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.formula;application/vnd.sun.xml.math
- Name=%PRODUCTNAME Math
- GenericName=Formula Editor
- Comment=Create and edit scientific formulas and equations by using Math.
-+InitialPreference=5
-diff --git sysui/desktop/menus/writer.desktop sysui/desktop/menus/writer.desktop
-index 0184d91..1509de0 100644
---- sysui/desktop/menus/writer.desktop
-+++ sysui/desktop/menus/writer.desktop
-@@ -9,3 +9,4 @@ MimeType=application/vnd.oasis.opendocument.text;application/vnd.oasis.opendocum
- Name=%PRODUCTNAME Writer
- GenericName=Word Processor
- Comment=Create and edit text and graphics in letters, reports, documents and Web pages by using Writer.
-+InitialPreference=5
---
-1.7.0.1
-
commit 237eaddb2f14aa249a839258c2f18b88cea1c525
Author: Rene Engelhard <rene at debian.org>
Date: Sat Jul 31 15:17:39 2010 -0400
stop mentioning mdds as extra source_file; is is a external tarball anyways
* download.in:
diff --git a/download.in b/download.in
index 562506e..85808e7 100755
--- a/download.in
+++ b/download.in
@@ -456,18 +456,6 @@ source_file( '@OOO_EXTRA_ARTWORK@' ) if '@OOO_EXTRA_ARTWORK@';
# Temporary utf-8ization of bibliograpy bits
source_file( "biblio.tar.bz2" );
-# Required to build sc.
-if ('@SYSTEM_MDDS@' ne 'YES') {
- $tag = "@CVSTAG@";
- $tag =~ tr/A-Z/a-z/;
- $tag =~ s/_m/-m/;
- $_ = $tag;
- ($mws, $minor) = split/-/;
- if (/ooo330/i || (/dev300/i && "$minor" ne "m84" )) {
- source_file( "cf8a6967f7de535ae257fa411c98eb88-mdds_0.3.0.tar.bz2" );
- }
-}
-
if (!$SPLIT && ($download_all || '@ENABLE_BINFILTER@' eq 'TRUE')) {
source_file_ooo( "binfilter" );
}
More information about the ooo-build-commit
mailing list
diff -u -u -r1.3 gnome-open-url.sh
--- shell/source/unix/misc/gnome-open-url.sh 13 May 2005 07:31:07 -0000 1.3
+++ shell/source/unix/misc/gnome-open-url.sh 6 Jun 2005 09:43:06 -0000
-@@ -1,6 +1,10 @@
+@@ -1,6 +1,6 @@
#!/bin/sh
--# use gnome-open utility coming with libgnome if available
--gnome-open "$1" 2>/dev/null || "$0.bin" $1
-+if which gnome-open; then
-+ # use gnome-open utility coming with libgnome if available
-+ gnome-open "$1" 2>/dev/null || "$0.bin" $1
-+else
-+ sensible-browser "$1"
-+fi
+ # use xdg-open or gnome-open if available
+-xdg-open "$1" 2>/dev/null || gnome-open "$1" 2>/dev/null || "$0.bin" $1
++xdg-open "$1" 2>/dev/null || gnome-open "$1" 2>/dev/null || sensible-browser "$1" || "$0.bin" $1
exit 0